Enum Class LabelSizeMode

java.lang.Object
java.lang.Enum<LabelSizeMode>
org.gephi.visualization.api.LabelSizeMode
All Implemented Interfaces:
Serializable, Comparable<LabelSizeMode>, Constable

public enum LabelSizeMode extends Enum<LabelSizeMode>
Defines how label sizes are determined during rendering.

Default value is ZOOM.

Author:
Mathieu Bastian
  • Enum Constant Details

    • SCREEN

      public static final LabelSizeMode SCREEN
      Label size remains constant in screen pixels regardless of zoom level.
    • ZOOM

      public static final LabelSizeMode ZOOM
      Label size scales with the zoom level.
  • Constructor Details

    • LabelSizeMode

      private LabelSizeMode()
  • Method Details

    • values

      public static LabelSizeMode[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static LabelSizeMode valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null