Uses of Enum Class
org.gephi.visualization.api.LabelSizeMode
Packages that use LabelSizeMode
-
Uses of LabelSizeMode in org.gephi.visualization.api
Methods in org.gephi.visualization.api that return LabelSizeModeModifier and TypeMethodDescriptionVisualizationModel.getEdgeLabelSizeMode()Returns the edge label size mode.VisualizationModel.getNodeLabelSizeMode()Returns the node label size mode.static LabelSizeModeReturns the enum constant of this class with the specified name.static LabelSizeMode[]LabelSizeMode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.gephi.visualization.api with parameters of type LabelSizeModeModifier and TypeMethodDescriptionvoidVisualizationController.setEdgeLabelSizeMode(LabelSizeMode mode) Sets the edge label size mode.voidVisualizationController.setNodeLabelSizeMode(LabelSizeMode mode) Sets the node label size mode.