Package org.gephi.visualization.api
Enum Class LabelSizeMode
- All Implemented Interfaces:
Serializable,Comparable<LabelSizeMode>,Constable
Defines how label sizes are determined during rendering.
Default value is ZOOM.
- Author:
- Mathieu Bastian
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum Constants -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic LabelSizeModeReturns the enum constant of this class with the specified name.static LabelSizeMode[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
SCREEN
Label size remains constant in screen pixels regardless of zoom level. -
ZOOM
Label size scales with the zoom level.
-
-
Constructor Details
-
LabelSizeMode
private LabelSizeMode()
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-