Package org.gephi.visualization.api
Interface ScreenshotModel
public interface ScreenshotModel
Screenshot-related settings.
- Author:
- Mathieu Bastian
-
Method Summary
Modifier and TypeMethodDescriptionReturns the default directory for saving screenshots.intReturns the scale factor for screenshots.Returns the visualization model associated with this screenshot model.booleanReturns whether the screenshot should be automatically saved to disk, or if a file chooser should be shown.booleanReturns whether the screenshot background should be transparent.
-
Method Details
-
getVisualizationModel
VisualizationModel getVisualizationModel()Returns the visualization model associated with this screenshot model.- Returns:
- the visualization model
-
getScaleFactor
int getScaleFactor()Returns the scale factor for screenshots.Default is 1. A scale factor of 2 means the screenshot will have twice the size of the surface.
- Returns:
- the scale factor
-
isTransparentBackground
boolean isTransparentBackground()Returns whether the screenshot background should be transparent.Default is false.
- Returns:
- true if the background is transparent
-
isAutoSave
boolean isAutoSave()Returns whether the screenshot should be automatically saved to disk, or if a file chooser should be shown.Default is false.
- Returns:
- true if the screenshot is auto-saved
-
getDefaultDirectory
String getDefaultDirectory()Returns the default directory for saving screenshots.When auto-save is enabled, screenshots will be saved in this directory.
- Returns:
- the default directory path as a string
-